@@ -32,6 +32,10 @@
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QDBusInterface>
+#include <QDir>
+#include <DWindowManagerHelper>
+#include <DForeignWindow>
+#include <QX11Info>
 
 #include <DApplication>
 
@@ -58,7 +62,20 @@ const qreal RESIZEPOINT_WIDTH = 15;
 MainWindow::MainWindow(QWidget *parent)
     : QLabel(parent)
 {
-//     startScreenshot();
+    setAttribute(Qt::WA_TranslucentBackground);
+    setWindowFlags(Qt::X11BypassWindowManagerHint);
+
+    installEventFilter(this);
+
+    connect(this, &MainWindow::releaseEvent, this, [=]{
+        qDebug() << "release event !!!";
+        m_keyboardReleased = true;
+        m_keyboardGrabbed =  windowHandle()->setKeyboardGrabEnabled(false);
+        qDebug() << "keyboardGrabbed:" << m_keyboardGrabbed;
+        removeEventFilter(this);
+    });
+
+    connect(this, &MainWindow::hideScreenshotUI, this, &MainWindow::hide);
 }
 
 MainWindow::~MainWindow()
@@ -72,10 +89,13 @@ void MainWindow::initOriginUI()
 
     QPoint curPos = this->cursor().pos();
 
+    const qreal ratio = devicePixelRatioF();
     m_swUtil = DScreenWindowsUtil::instance(curPos);
     m_screenNum =  m_swUtil->getScreenNum();
     m_backgroundRect = m_swUtil->backgroundRect();
-    this->move(m_backgroundRect.x(), m_backgroundRect.y());
+    m_backgroundRect = QRect(m_backgroundRect.topLeft() / ratio, m_backgroundRect.size());
+
+    move(m_backgroundRect.topLeft() * ratio);
     this->setFixedSize(m_backgroundRect.size());
     initBackground();
 
@@ -113,10 +133,17 @@ void MainWindow::initOriginUI()
 
 void MainWindow::initSecondUI()
 {
-    if (m_screenNum == 0) {
-        m_windowRects = m_swUtil->windowsRect();
-        m_windowNames = m_swUtil->windowsName();
+    for (auto wid : DWindowManagerHelper::instance()->currentWorkspaceWindowIdList()) {
+        if (wid == winId()) continue;
+
+        DForeignWindow * window = DForeignWindow::fromWinId(wid);
+        if (window) {
+            window->deleteLater();
+            m_windowRects << window->geometry();
+            m_windowNames << window->wmClass();
+        }
     }
+
     m_configSettings =  ConfigSettings::instance();
     m_toolBar = new ToolBar(this);
     m_toolBar->hide();
@@ -241,7 +268,7 @@ void MainWindow::keyPressEvent(QKeyEvent *keyEvent)
             } else if (keyEvent->key() == Qt::Key_Down) {
                 m_shapesWidget->microAdjust("Ctrl+Down");
             } else if (keyEvent->key() == Qt::Key_C) {
-                ConfigSettings::instance()->setValue("save", "save_op", 3);
+                ConfigSettings::instance()->setValue("save", "save_op", SaveAction::SaveToClipboard);
                 saveScreenshot();
             } else if (keyEvent->key() == Qt::Key_S) {
                 expressSaveScreenshot();
@@ -298,7 +325,7 @@ void MainWindow::keyPressEvent(QKeyEvent *keyEvent)
             }
 
             if (keyEvent->key() == Qt::Key_C) {
-                ConfigSettings::instance()->setValue("save", "save_op", 3);
+                ConfigSettings::instance()->setValue("save", "save_op", SaveAction::SaveToClipboard);
                 saveScreenshot();
             }
 
@@ -507,6 +534,16 @@ void MainWindow::hideEvent(QHideEvent *event)
     QLabel::hideEvent(event);
 }
 
+bool MainWindow::eventFilter(QObject *watched, QEvent *event)
+{
+    if (!m_keyboardGrabbed && this->windowHandle() != NULL) {
+        m_keyboardGrabbed = this->windowHandle()->setKeyboardGrabEnabled(true);
+        qDebug() << "m_keyboardGrabbed:" << m_keyboardGrabbed;
+    }
+
+    return QLabel::eventFilter(watched, event);
+}
+
 void MainWindow::mouseMoveEvent(QMouseEvent *ev)
 {
     bool needRepaint = false;
@@ -526,22 +563,24 @@ void MainWindow::mouseMoveEvent(QMouseEvent *ev)
             if (!m_toolBar->isVisible() && !m_isFirstReleaseButton) {
                 QPoint curPos = this->cursor().pos();
                 QPoint tmpPos;
-                if (curPos.x() + INDICATOR_WIDTH + CURSOR_WIDTH > m_backgroundRect.x()
+                QPoint topLeft = m_backgroundRect.topLeft() * devicePixelRatioF();
+
+                if (curPos.x() + INDICATOR_WIDTH + CURSOR_WIDTH > topLeft.x()
                         + m_backgroundRect.width()) {
                       tmpPos.setX(curPos.x() - INDICATOR_WIDTH);
                 } else {
                     tmpPos.setX(curPos.x() + CURSOR_WIDTH);
                 }
 
-                if (curPos.y() + INDICATOR_WIDTH > m_backgroundRect.y() + m_backgroundRect.height()) {
+                if (curPos.y() + INDICATOR_WIDTH > topLeft.y() + m_backgroundRect.height()) {
                     tmpPos.setY(curPos.y() - INDICATOR_WIDTH);
                 } else {
                     tmpPos.setY(curPos.y() + CURSOR_HEIGHT);
                 }
 
                 m_zoomIndicator->showMagnifier(QPoint(
-                    std::max(tmpPos.x() - m_backgroundRect.x(), 0),
-                    std::max(tmpPos.y() - m_backgroundRect.y(), 0)));
+                    std::max(tmpPos.x() - topLeft.x(), 0),
+                    std::max(tmpPos.y() - topLeft.y(), 0)));
             }
         } else {
             m_isFirstMove = true;
@@ -601,30 +640,17 @@ void MainWindow::mouseMoveEvent(QMouseEvent *ev)
                 needRepaint = true;
             }
         } else {
-            if (m_screenNum == 0) {
-                for (int i = 0; i < m_windowRects.length(); i++) {
-                    int wx = m_windowRects[i].x();
-                    int wy = m_windowRects[i].y();
-                    int ww = m_windowRects[i].width();
-                    int wh = m_windowRects[i].height();
-                    int ex = ev->x();
-                    int ey = ev->y();
-                    if (ex > wx && ex < wx + ww && ey > wy && ey < wy + wh) {
-                        m_recordX = wx;
-                        m_recordY = wy;
-                        m_recordWidth = ww;
-                        m_recordHeight = wh;
+            const QPoint mousePoint = QCursor::pos();
+            for (auto it = m_windowRects.rbegin(); it != m_windowRects.rend(); ++it) {
+                if (it->contains(mousePoint)) {
+                    m_recordX = it->x() - static_cast<int>(m_backgroundRect.x() * devicePixelRatioF());
+                    m_recordY = it->y() - static_cast<int>(m_backgroundRect.y() * devicePixelRatioF());
+                    m_recordWidth = it->width();
+                    m_recordHeight = it->height();
 
-                        needRepaint = true;
-                        break;
-                    }
+                    needRepaint = true;
+                    break;
                 }
-            } else {
-                m_recordX = 0;
-                m_recordY = 0;
-                m_recordWidth = m_backgroundRect.width();
-                m_recordHeight = m_backgroundRect.height();
-                needRepaint = true;
             }
         }
 
@@ -1128,10 +1154,16 @@ void MainWindow::startScreenshot()
 
 QPixmap MainWindow::getPixmapofRect(const QRect &rect)
 {
-    const qreal dpr = qApp->devicePixelRatio();
-    return m_swUtil->primaryScreen()->grabWindow(
-                m_swUtil->rootWindowId(),
-               rect.x() / dpr, rect.y() / dpr, rect.width(), rect.height());
+    QRect r(rect.topLeft() * devicePixelRatioF(), rect.size());
+
+    QList<QScreen*> screenList = qApp->screens();
+    for (auto it = screenList.constBegin(); it != screenList.constEnd(); ++it) {
+        if ((*it)->geometry().contains(r)) {
+            return (*it)->grabWindow(m_swUtil->rootWindowId(), rect.x(), rect.y(), rect.width(), rect.height());
+        }
+    }
+
+    return QPixmap();
 }
 
 void MainWindow::initBackground()
@@ -1189,7 +1221,9 @@ void MainWindow::shotImgWidthEffect()
 //    eventloop.exec();
 
     qDebug() << m_toolBar->isVisible() << m_sizeTips->isVisible();
-    m_resultPixmap = getPixmapofRect(m_shapesWidget->geometry());
+    const qreal ratio = devicePixelRatioF();
+    const QRect rect(m_shapesWidget->geometry().topLeft() * ratio, m_shapesWidget->geometry().size() * ratio);
+    m_resultPixmap = m_backgroundPixmap.copy(rect);
     m_drawNothing = false;
     update();
 }
@@ -1227,25 +1261,27 @@ bool MainWindow::saveAction(const QPixmap &pix)
     QStandardPaths::StandardLocation saveOption = QStandardPaths::TempLocation;
     bool copyToClipboard = false;
 
-    if (ConfigSettings::instance()->hasTemporarySaveAction()) {
-        m_saveIndex = ConfigSettings::instance()->getAndResetTemporarySaveAction();
-    } else {
-        m_saveIndex = ConfigSettings::instance()->value("save", "save_op").toInt();
+    std::pair<bool, SaveAction> temporarySaveAction = ConfigSettings::instance()->getTemporarySaveAction();
+    if (temporarySaveAction.first) {
+        m_saveIndex = temporarySaveAction.second;
+    }
+    else {
+        m_saveIndex = ConfigSettings::instance()->value("save", "save_op").value<SaveAction>();
     }
     switch (m_saveIndex) {
-    case 0: {
+    case SaveToDesktop: {
         saveOption = QStandardPaths::DesktopLocation;
         ConfigSettings::instance()->setValue("common", "default_savepath", QStandardPaths::writableLocation(
                                                  QStandardPaths::DesktopLocation));
         break;
     }
-    case 1: {
+    case AutoSave: {
         QString defaultSaveDir = ConfigSettings::instance()->value("common", "default_savepath").toString();
         if (defaultSaveDir.isEmpty()) {
             saveOption = QStandardPaths::DesktopLocation;
         } else if (defaultSaveDir == "clipboard") {
             copyToClipboard = true;
-            m_saveIndex = 3;
+            m_saveIndex = SaveToSpecificDir;
         } else {
             if (m_selectAreaName.isEmpty()) {
                 m_saveFileName = QString("%1/%2_%3.png").arg(defaultSaveDir).arg(tr(
@@ -1257,20 +1293,27 @@ bool MainWindow::saveAction(const QPixmap &pix)
         }
         break;
     }
-    case 2: {
+    case SaveToSpecificDir: {
         this->hide();
         this->releaseKeyboard();
-        QFileDialog fileDialog;
-        QString  lastFileName;
-        if (m_selectAreaName.isEmpty()) {
-            lastFileName = QString("%1/%2_%3.png").arg(QStandardPaths::writableLocation(
-                                        QStandardPaths::PicturesLocation)).arg(tr("DeepinScreenshot")).arg(currentTime);
-        } else {
-            lastFileName = QString("%1/%2_%3_%4.png").arg(QStandardPaths::writableLocation(
-                                         QStandardPaths::PicturesLocation)).arg(tr("DeepinScreenshot")
-                                                                                                     ).arg(m_selectAreaName).arg(currentTime);
+
+        QString path = ConfigSettings::instance()->value("common", "default_savepath").toString();
+        QString fileName = m_selectAreaName;
+
+        if (path.isEmpty() || !QDir(path).exists()) {
+            path = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation);
         }
 
+        if (fileName.isEmpty()) {
+            fileName = QString("%1_%2").arg(tr("DeepinScreenshot")).arg(currentTime);
+        }
+        else {
+            fileName = QString("%1_%2_%3").arg(tr("DeepinScreenshot")).arg(m_selectAreaName).arg(currentTime);
+        }
+
+        QString lastFileName = QString("%1/%2.png").arg(path).arg(fileName);
+
+        QFileDialog fileDialog;
         m_saveFileName =  fileDialog.getSaveFileName(this, "Save",  lastFileName,
                                                      tr("PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;"
                                                         "XBM (*.xbm);;XPM(*.xpm)"));
@@ -1290,18 +1333,18 @@ bool MainWindow::saveAction(const QPixmap &pix)
                                              QFileInfo(m_saveFileName).dir().absolutePath());
         break;
     }
-    case 3: {
+    case SaveToClipboard: {
         copyToClipboard = true;
         ConfigSettings::instance()->setValue("common", "default_savepath",   "clipboard");
         break;
     }
-    case 4: {
+    case SaveToAutoClipboard: {
         copyToClipboard = true;
         QString defaultSaveDir = ConfigSettings::instance()->value("common", "default_savepath").toString();
         if (defaultSaveDir.isEmpty()) {
             saveOption = QStandardPaths::DesktopLocation;
         } else if (defaultSaveDir == "clipboard") {
-            m_saveIndex = 3;
+            m_saveIndex = SaveToSpecificDir;
         } else  {
             if (m_selectAreaName.isEmpty()) {
                 m_saveFileName = QString("%1/%2_%3.png").arg(defaultSaveDir).arg(tr(
@@ -1331,18 +1374,26 @@ bool MainWindow::saveAction(const QPixmap &pix)
                                                                             Qt::KeepAspectRatio, Qt::FastTransformation);
     }
 
-    if (m_saveIndex == 2 && m_saveFileName.isEmpty()) {
+    if (m_saveIndex == SaveToSpecificDir && m_saveFileName.isEmpty()) {
         return false;
-    } else if (m_saveIndex == 2 || !m_saveFileName.isEmpty()) {
+    } else if (m_saveIndex == SaveToSpecificDir || !m_saveFileName.isEmpty()) {
         if (!screenShotPix.save(m_saveFileName,  QFileInfo(m_saveFileName).suffix().toLocal8Bit()))
             return false;
     } else if (saveOption != QStandardPaths::TempLocation && m_saveFileName.isEmpty()) {
+        QString savePath = QStandardPaths::writableLocation(saveOption);
+        QDir saveDir(savePath);
+        if (!saveDir.exists()) {
+            bool mkdirSucc = saveDir.mkpath(".");
+            if (!mkdirSucc) {
+                qCritical() << "Save path not exist and cannot be created:" << savePath;
+                qCritical() << "Fall back to temp location!";
+                savePath = QDir::tempPath();
+            }
+        }
         if (m_selectAreaName.isEmpty()) {
-            m_saveFileName = QString("%1/%2_%3.png").arg(QStandardPaths::writableLocation(
-                             saveOption)).arg(tr("DeepinScreenshot")).arg(currentTime);
+            m_saveFileName = QString("%1/%2_%3.png").arg(savePath, tr("DeepinScreenshot"), currentTime);
         } else {
-            m_saveFileName = QString("%1/%2_%3_%4.png").arg(QStandardPaths::writableLocation(
-                             saveOption)).arg(tr("DeepinScreenshot")).arg(m_selectAreaName).arg(currentTime);
+            m_saveFileName = QString("%1/%2_%3_%4.png").arg(savePath, tr("DeepinScreenshot"), m_selectAreaName, currentTime);
         }
         if (!screenShotPix.save(m_saveFileName,  "PNG"))
             return false;
@@ -1357,7 +1408,7 @@ bool MainWindow::saveAction(const QPixmap &pix)
     return true;
 }
 
-void MainWindow::sendNotify(int saveIndex, QString saveFilePath, const bool succeed)
+void MainWindow::sendNotify(SaveAction saveAction, QString saveFilePath, const bool succeed)
 {
     // failed notify
     if (!succeed)
@@ -1395,17 +1446,17 @@ void MainWindow::sendNotify(int saveIndex, QString saveFilePath, const bool succ
     qDebug() << "saveFilePath:" << saveFilePath;
 
     QString summary;
-    if (saveIndex == 3) {
+    if (saveAction == SaveAction::SaveToClipboard) {
         summary = QString(tr("Picture has been saved to clipboard"));
     } else {
         summary = QString(tr("Picture has been saved to %1")).arg(saveFilePath);
     }
 
-    if (saveIndex == 3 && !m_noNotify) {
+    if (saveAction == SaveAction::SaveToClipboard && !m_noNotify) {
         QVariantMap emptyMap;
         m_notifyDBInterface->Notify("Deepin Screenshot", 0,  "deepin-screenshot", "",
                                     summary,  QStringList(), emptyMap, 0);
-    }  else if ( !m_noNotify &&  !(m_saveIndex == 2 && m_saveFileName.isEmpty())) {
+    }  else if ( !m_noNotify &&  !(m_saveIndex == SaveAction::SaveToSpecificDir && m_saveFileName.isEmpty())) {
         m_notifyDBInterface->Notify("Deepin Screenshot", 0,  "deepin-screenshot", "",
                                     summary, actions, hints, 0);
     }
@@ -1472,7 +1523,7 @@ void MainWindow::onHelp()
         iface.call("ShowManual", "deepin-screenshot");
         exitApp();
     } else {
-        qWarning() << "manual service not avilable, cannot open manual";
+        qWarning() << "manual service not available, cannot open manual";
     }
 }
 
