@@ -1,12 +1,10 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
 <context>
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.cpp" line="641"/>
         <source>select-area</source>
-        <translation type="unfinished"></translation>
+        <translation>select-area</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="986"/>
@@ -20,34 +18,34 @@
         <location filename="../mainwindow.cpp" line="1337"/>
         <location filename="../mainwindow.cpp" line="1340"/>
         <source>DeepinScreenshot</source>
-        <translation type="unfinished"></translation>
+        <translation>DeepinScreenshot</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1004"/>
         <location filename="../mainwindow.cpp" line="1366"/>
         <source>View</source>
-        <translation type="unfinished"></translation>
+        <translation>View</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1018"/>
         <location filename="../mainwindow.cpp" line="1386"/>
         <source>Picture has been saved to %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Picture has been saved to %1</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1270"/>
         <source>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</source>
-        <translation type="unfinished"></translation>
+        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1360"/>
         <source>Save failed. Please save it in your home directory.</source>
-        <translation type="unfinished"></translation>
+        <translation>Save failed. Please save it in your home directory.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1384"/>
         <source>Picture has been saved to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Picture has been saved to clipboard</translation>
     </message>
 </context>
 <context>
@@ -55,67 +53,67 @@
     <message>
         <location filename="../controller/menucontroller.cpp" line="40"/>
         <source>Rectangle</source>
-        <translation type="unfinished"></translation>
+        <translation>Rectangle</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="48"/>
         <source>Ellipse</source>
-        <translation type="unfinished"></translation>
+        <translation>Ellipse</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="56"/>
         <source>Arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Arrow</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="64"/>
         <source>Pencil</source>
-        <translation type="unfinished"></translation>
+        <translation>Pencil</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="72"/>
         <source>Text</source>
-        <translation type="unfinished"></translation>
+        <translation>Text</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="80"/>
         <source>Undo</source>
-        <translation type="unfinished"></translation>
+        <translation>Undo</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="96"/>
         <source>Save</source>
-        <translation type="unfinished"></translation>
+        <translation>Save</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="99"/>
         <source>Save to desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Save to desktop</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="100"/>
         <source>Autosave</source>
-        <translation type="unfinished"></translation>
+        <translation>Autosave</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="101"/>
         <source>Save to specified folder</source>
-        <translation type="unfinished"></translation>
+        <translation>Save to specified folder</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="102"/>
         <source>Copy to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Copy to clipboard</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="103"/>
         <source>Autosave and copy to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Autosave and copy to clipboard</translation>
     </message>
     <message>
         <location filename="../controller/menucontroller.cpp" line="124"/>
         <source>Exit</source>
-        <translation type="unfinished"></translation>
+        <translation>Exit</translation>
     </message>
 </context>
 <context>
@@ -123,7 +121,7 @@
     <message>
         <location filename="../screenshot.cpp" line="78"/>
         <source>Deepin Screenshot will start after %1 seconds</source>
-        <translation type="unfinished"></translation>
+        <translation>Deepin Screenshot will start after %1 seconds</translation>
     </message>
 </context>
 <context>
@@ -131,123 +129,123 @@
     <message>
         <location filename="../utils/shortcut.cpp" line="29"/>
         <source>Start/Screenshot</source>
-        <translation type="unfinished"></translation>
+        <translation>Start/Screenshot</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="30"/>
         <location filename="../utils/shortcut.cpp" line="41"/>
         <source>Save</source>
-        <translation type="unfinished"></translation>
+        <translation>Save</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="31"/>
         <source>Painting</source>
-        <translation type="unfinished"></translation>
+        <translation>Painting</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="32"/>
         <source>Size Adjustment</source>
-        <translation type="unfinished"></translation>
+        <translation>Size Adjustment</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="35"/>
         <source>Quick start</source>
-        <translation type="unfinished"></translation>
+        <translation>Quick start</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="36"/>
         <source>Full screenshot</source>
-        <translation type="unfinished"></translation>
+        <translation>Full screenshot</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="37"/>
         <source>Delay screenshot</source>
-        <translation type="unfinished"></translation>
+        <translation>Delay screenshot</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="38"/>
         <source>Undo</source>
-        <translation type="unfinished"></translation>
+        <translation>Undo</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="39"/>
         <source>Exit</source>
-        <translation type="unfinished"></translation>
+        <translation>Exit</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="42"/>
         <source>Copy to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Copy to clipboard</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="45"/>
         <source>Rectangle</source>
-        <translation type="unfinished"></translation>
+        <translation>Rectangle</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="46"/>
         <source>Ellipse</source>
-        <translation type="unfinished"></translation>
+        <translation>Ellipse</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="47"/>
         <source>Arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Arrow</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="48"/>
         <source>Pencil</source>
-        <translation type="unfinished"></translation>
+        <translation>Pencil</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="49"/>
         <source>Text</source>
-        <translation type="unfinished"></translation>
+        <translation>Text</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="50"/>
         <source>Color</source>
-        <translation type="unfinished"></translation>
+        <translation>Color</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="53"/>
         <source>Increase height up</source>
-        <translation type="unfinished"></translation>
+        <translation>Increase height up</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="54"/>
         <source>Increase height down</source>
-        <translation type="unfinished"></translation>
+        <translation>Increase height down</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="55"/>
         <source>Increase width left</source>
-        <translation type="unfinished"></translation>
+        <translation>Increase width left</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="56"/>
         <source>Increase width right</source>
-        <translation type="unfinished"></translation>
+        <translation>Increase width right</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="57"/>
         <source>Decrease height up</source>
-        <translation type="unfinished"></translation>
+        <translation>Decrease height up</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="58"/>
         <source>Decrease height down</source>
-        <translation type="unfinished"></translation>
+        <translation>Decrease height down</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="59"/>
         <source>Decrease width left</source>
-        <translation type="unfinished"></translation>
+        <translation>Decrease width left</translation>
     </message>
     <message>
         <location filename="../utils/shortcut.cpp" line="60"/>
         <source>Decrease width right</source>
-        <translation type="unfinished"></translation>
+        <translation>Decrease width right</translation>
     </message>
 </context>
 <context>
@@ -255,37 +253,37 @@
     <message>
         <location filename="../widgets/subtoolbar.cpp" line="397"/>
         <source>Save to desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Save to desktop</translation>
     </message>
     <message>
         <location filename="../widgets/subtoolbar.cpp" line="403"/>
         <source>Autosave</source>
-        <translation type="unfinished"></translation>
+        <translation>Autosave</translation>
     </message>
     <message>
         <location filename="../widgets/subtoolbar.cpp" line="409"/>
         <source>Save to specified folder</source>
-        <translation type="unfinished"></translation>
+        <translation>Save to specified folder</translation>
     </message>
     <message>
         <location filename="../widgets/subtoolbar.cpp" line="415"/>
         <source>Copy to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Copy to clipboard</translation>
     </message>
     <message>
         <location filename="../widgets/subtoolbar.cpp" line="420"/>
         <source>Autosave and copy to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Autosave and copy to clipboard</translation>
     </message>
     <message>
         <location filename="../widgets/subtoolbar.cpp" line="425"/>
         <source>Low</source>
-        <translation type="unfinished"></translation>
+        <translation>Low</translation>
     </message>
     <message>
         <location filename="../widgets/subtoolbar.cpp" line="439"/>
         <source>High</source>
-        <translation type="unfinished"></translation>
+        <translation>High</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
